@@ -63,19 +63,22 @@ static void S_null_suspendhook(pTHX_ U8 phase, CV *cv, HV *modhookdata)
   /* empty */
 }
 
+#ifndef OP_CHECK_MUTEX_LOCK /* < 5.15.8 */
+#  define OP_CHECK_MUTEX_LOCK ((void)0)
+#  define OP_CHECK_MUTEX_UNLOCK ((void)0)
+#endif
+
 #define future_asyncawait_wrap_suspendhook(newfunc, oldhookp) S_future_asyncawait_wrap_suspendhook(aTHX_ newfunc, oldhookp)
 static void S_future_asyncawait_wrap_suspendhook(pTHX_ SuspendHookFunc *newfunc, SuspendHookFunc **oldhookp)
 {
   if(*oldhookp)
     return;
 
-#if defined(USE_ITHREADS) && (PERL_REVISION == 5) && (PERL_VERSION >= 16)
   /* Rather than define our own mutex for this very-rare usecase, we'll just
    * abuse core's opcheck mutex for it. At worst this leads to thread
    * contention at module load time for this very quick test
    */
-  MUTEX_LOCK(&PL_check_mutex);
-#endif
+  OP_CHECK_MUTEX_LOCK;
 
   if(!*oldhookp) {
     SV **hookp = hv_fetchs(PL_modglobal, "Future::AsyncAwait/suspendhook", TRUE);
@@ -87,9 +90,7 @@ static void S_future_asyncawait_wrap_suspendhook(pTHX_ SuspendHookFunc *newfunc,
     sv_setuv(*hookp, PTR2UV(newfunc));
   }
 
-#if defined(USE_ITHREADS) && (PERL_REVISION == 5) && (PERL_VERSION >= 16)
-  MUTEX_UNLOCK(&PL_check_mutex);
-#endif
+  OP_CHECK_MUTEX_UNLOCK;
 }
 
 #endif
